/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_CONF_SRC_CONF_YACC_H_INCLUDED
# define YY_CONF_SRC_CONF_YACC_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int confdebug;
#endif
/* "%code requires" blocks.  */
#line 1 "src/conf_yacc.y"

#include "conf_ast.h"

#line 53 "src/conf_yacc.h"

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TDEFINE = 258,                 /* "@@define"  */
    TUNDEFINE = 259,               /* "@@undef"  */
    TIFDEF = 260,                  /* "@@ifdef"  */
    TIFNDEF = 261,                 /* "@@ifndef"  */
    TIFNHOST = 262,                /* "@@ifnhost"  */
    TIFHOST = 263,                 /* "@@ifhost"  */
    TIF = 264,                     /* "@@if"  */
    TBOOLNOT = 265,                /* "not"  */
    TBOOLFUNC = 266,               /* "boolean function"  */
    TBOOLOP = 267,                 /* "boolean operator"  */
    TELSE = 268,                   /* "@@else"  */
    TENDIF = 269,                  /* "@@endif"  */
    TINCLUDE = 270,                /* "@@include"  */
    TXINCLUDE = 271,               /* "@@x_include"  */
    TSETENV = 272,                 /* "@@x_include_setenv"  */
    TGROUP = 273,                  /* "group name"  */
    TSTRING = 274,                 /* "string"  */
    TEXPR = 275,                   /* "group"  */
    TVARIABLE = 276,               /* "variable name"  */
    TSPACE = 277,                  /* "whitespace"  */
    TNEWLINE = 278,                /* "new line"  */
    TSELRXRULE = 279,              /* "regular rule"  */
    TEQURXRULE = 280,              /* "equals rule"  */
    TRECNEGRXRULE = 281,           /* "recursive negative rule"  */
    TNONRECNEGRXRULE = 282,        /* "non-recursive negative rule"  */
    CONFIGOPTION = 283             /* "configuration option"  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEMPTY -2
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define TDEFINE 258
#define TUNDEFINE 259
#define TIFDEF 260
#define TIFNDEF 261
#define TIFNHOST 262
#define TIFHOST 263
#define TIF 264
#define TBOOLNOT 265
#define TBOOLFUNC 266
#define TBOOLOP 267
#define TELSE 268
#define TENDIF 269
#define TINCLUDE 270
#define TXINCLUDE 271
#define TSETENV 272
#define TGROUP 273
#define TSTRING 274
#define TEXPR 275
#define TVARIABLE 276
#define TSPACE 277
#define TNEWLINE 278
#define TSELRXRULE 279
#define TEQURXRULE 280
#define TRECNEGRXRULE 281
#define TNONRECNEGRXRULE 282
#define CONFIGOPTION 283

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 42 "src/conf_yacc.y"

  char* s;

  config_option option;

  bool_operator operator;

  ast* ast;

  if_condition* if_cond;
  bool_expression* bool_expr;
  attribute_expression* attr_expr;
  restriction_expression* rs_expr;
  ft_restriction_expression* ft_rs_expr;
  string_expression* string_expr;

#line 146 "src/conf_yacc.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE conflval;


int confparse (ast** config_ast);


#endif /* !YY_CONF_SRC_CONF_YACC_H_INCLUDED  */
